*****************************************************************************************************************************************************************************************************************************************
*TITLE: WHEN RICHER DOESN'T MEAN THINNER: ETHNICITY, SOCIO-ECONOMIC POSITION AND THE RISK OF CHILD OBESITY IN THE U.K.
*AUTHORS: ALICE GOISIS, MELISSA MARTINSON, WENDY SIGLE
*Dataset used: UK Millennium Cohort Study
*Sweeps: 1 and 4
*****************************************************************************************************************************************************************************************************************************************

***********************
*****MCS SWEEP 1*******
***********************

***********************************
***MAIN RESPONDENTS AND PARTNER****
***********************************
gen resp_natural_parent=1 if amcrel00==7
replace resp_natural_parent=0 if amcrel00!=7
/*main respondent is cohort member natural parent*/

gen partner_natural_parent=1 if apcrel00==7
replace partner_natural_parent=0 if apcrel00!=7
/*partner is cohort member natural parent*/

recode ampsex00 (1=0 "male") (2=1 "female"), gen (resp_sex)
recode appsex00 (1=0 "male") (2=1 "female"), gen (partner_sex)
/*main respondent and partner sex*/

gen mother_main_1=1 if resp_natural_parent==1&resp_sex==1
replace mother_main_1=0 if resp_natural_parent!=1|resp_sex==0

***********
***SEX*****
***********

replace ahcsexa0=bhcsexa0 if ahcsexa0==.

gen sex=0 if ahcsexa0==2
replace sex=1 if ahcsexa0==1

label define sex 0 "girl" 1 "boy" 
label values sex sex

gen girl=1 if sex==0
replace girl=0 if sex==1

*********************
*****TWIN/TRIPLET****
*********************

rename nocmhh num_babies
/*number of cohort babies*/

gen single_birth=1 if num_babies==1
replace single_birth=0 if num_babies!=1 & num_babies!=.

gen twin_birth=1 if num_babies==2
replace twin_birth=0 if num_babies!=2 & num_babies!=.

gen triplet_birth=1 if num_babies==3
replace triplet_birth=0 if num_babies!=3 & num_babies!=.

********************
****BREASTFEEDING***
********************

recode ambfeva0 (1=1 "yes") (2=0 "no") (-9 -8 -1=.), gen (ever_breastfeed)
replace ever_breastfeed=0 if ambfeaa0==1
/* in the following question it says that cohort child never took breastfeeding milk */

gen breastfeed_0=0
replace breastfeed_0=1 if ever_breastfeed==0
replace breastfeed_0=. if ever_breastfeed==.

gen breastfeed_0_2=0
replace breastfeed_0_2=1 if ambfeaa0==2|ambfeaa0==3 & ambfeda0<=60|ambfeaa0==4 & ambfewa0<=8|ambfeaa0==5 & ambfema0<=2
replace breastfeed_0_2=. if ever_breastfeed==.

gen breastfeed_2_4=0
replace breastfeed_2_4=1 if (ambfeaa0==4 & (ambfewa0<=16 & ambfewa0>8))|(ambfeaa0==5 & (ambfema0<=4 & ambfema0>2))
replace breastfeed_2_4=. if ever_breastfeed==.

gen breastfeed_4=0
replace breastfeed_4=1 if ambfeaa0==4 & ambfewa0>16|ambfeaa0==5 & ambfema0>4|ambfeaa0==6
replace breastfeed_4=. if ever_breastfeed==.

gen breastfeed=0 if breastfeed_0==1
replace breastfeed=1 if breastfeed_0_2==1
replace breastfeed=2 if breastfeed_2_4==1
replace breastfeed=3 if breastfeed_4==1

label define breastfeed 0 "never" 1"up to 2 months" 2"up to 4 months" 3"more than 4 months"
label values breastfeed breastfeed

gen some_breastfeeding=1 if breastfeed>=1&breastfeed<=3
replace some_breastfeeding=0 if breastfeed==0
	
*********************************
****INTRODUCTION TO SOLID FOODS**
*********************************

recode amagsfa0 -8 -1=.
recode amsfwka0 -1=.
recode amsfmta0 -8 -1=. 

gen solid_food_before_4=0
replace solid_food_before_4=1 if amagsfa0==2
replace solid_food_before_4=1 if amagsfa0==3 & amsfwka0<16
replace solid_food_before_4=1 if amagsfa0==4 & amsfmta0<4 
replace solid_food_before_4=0 if amagsfa0==1
replace solid_food_before_4=. if amagsfa0==.

label var solid_food_before_4 "S1 CM introduced to solid food before 4 months"

*************************
*SMOKE DURING PREGNANCY**
*************************

recode amsmus0a (1=0 "no") (2 3 4 95=1 "yes") (-8 -1=.), gen(currently_smoking)
/*MAIN is currently smoking*/

recode amsmty00 (1=1 "yes") (2=0 "no") (-1=.), gen (smoke_last_2yrs)
/*for those who are not currently smoking: whether they smoked in the past 2 years*/

rename amcipr00 ciga_pre_preg
recode ciga_pre_preg -1 -8=.
/*for those who have smoked in the past 2 years: number of cigarettes smoked per day before pregnancy*/

recode amsmch00 (1=1 "yes") (2=0 "no") (-8 -1 3=.), gen (change_smoke_preg)
/*whether changed your smoking habit during pregnancy*/

rename amcich00 ciga_post_change	
recode ciga_post_change -8 -1 97=.
recode ciga_post_change 96=1
/*cigarettes smoked after change; 0=quit smoking*/

recode amwhch00 -8 -1=.

**MAIN smoke during pregnancy
gen smoke_preg=0 if smoke_last_2yrs==0
*has not smoked for the past two years
replace smoke_preg=1 if (ciga_pre_preg!=0 & ciga_pre_preg!=.) & (ciga_post_change!=0 & ciga_post_change!=.)
*was smoking before pregnancy, has changed habit but has not reduced to 0 the number of cigarettes smoked during pregnancy
replace smoke_preg=1 if (ciga_pre_preg!=0 & ciga_pre_preg!=.) & change_smoke_preg==0
*was smoking before pregnancy and has not changed habit
replace smoke_preg=0 if ciga_pre_preg==0&change_smoke_preg==0
*has smoked over the past two years, but wasn't smoking before pregnancy and hasn't changed during pregnancy
replace smoke_preg=0 if ciga_pre_preg==0&change_smoke_preg==1&ciga_post_change==0
*has smoked over the past two years, wasn't smoking before pregnancy, has changed cigarette smoking, but declares not to have smoked during pregnancy (for this group a change didn't really occur but it wouldn't make sense to drop them)
replace smoke_preg=0 if ciga_pre_preg>0 & ciga_pre_preg!=. & (amwhch00==1|amwhch00==2) & ciga_post_change==0
*was smoking just before pregnancy, but has quit during the first two months (75% quit within 2 months) - this group could also be coded as smoking if one wanted to strictly look at exposure vs. non exposure
replace smoke_preg=1 if (ciga_pre_preg>0 & ciga_pre_preg!=.) & ciga_post_change==0 & amwhch00>2 & amwhch00!=.
*was smoking before pregnancy, has quit smoking but not during the first month
replace smoke_preg=1 if ciga_pre_preg==0&change_smoke_preg==1&ciga_post_change!=0
*has smoked over the past two years, wasnt' smoking before pregnancy and has changed smoking habit to some cigarettes during pregnancy

label var smoke_preg "S1 MAIN smoked during pregnancy"

**********************
******ETHNICITY*******
**********************

recode DDC08EA0 -1=.
gen ethnicity=1 if DDC08EA0==1
replace ethnicity=2 if DDC08EA0==3
replace ethnicity=3 if DDC08EA0==4|DDC08EA0==5
replace ethnicity=4 if DDC08EA0==6|DDC08EA0==7
replace ethnicity=5 if DDC08EA0==8|DDC08EA0==2

label var ethnicity "S1 CM ethnic group"
label define ethnic 1"white" 2"indian" 3"pakistani/bangladeshi" 4"black caribbean/african" 5"other/mixed"
label values ethnicity ethnic

recode AMD08E00 -9 -8=.
gen main_ethnicity=1 if  AMD08E00==1
replace main_ethnicity=2 if AMD08E00==3
replace main_ethnicity=3 if AMD08E00==4|AMD08E00==5
replace main_ethnicity=4 if AMD08E00==6|AMD08E00==7

label var main_ethnicity "S1 MAIN resp ethnic group"
label define ethnicity 1 "white" 2"indian" 3"pakistani/bangladeshi" 4"black car/african" 
label values main_ethnicity ethnicity

gen white=1 if main_ethnicity==1
replace white=0 if main_ethnicity!=1 & main_ethnicity!=.

gen indian=1 if main_ethnicity==2
replace indian=0 if main_ethnicity!=2 & main_ethnicity!=.

gen pakibangla=1 if main_ethnicity==3
replace pakibangla=0 if main_ethnicity!=3 & main_ethnicity!=.

gen black=1 if main_ethnicity==4
replace black=0 if main_ethnicity!=4 & main_ethnicity!=.

**************************************************
*****************PARITY***************************
**************************************************

**living in the household
gen natural_parent=0
foreach i in a0 b0 c0 d0 e0 f0 g0 h0 i0 j0 k0{
replace natural_parent=1 if amprel`i'==7
}
replace natural_parent=. if amprela0==.
gen num_bio_cld=0
foreach i in a0 b0 c0 d0 e0 f0 g0 h0 i0 j0 k0{
replace num_bio_cld=num_bio_cld+1 if amprel`i'==7
}
replace num_bio_cld=. if amprela0==.
*
/* there are a few cases mismatched wrt to the derived variable adnsib00. 
variable derived from ahprel`i' -- relationship of hh member to cohort member(s) - this is wrong to use. 
the CM can have step siblings who are the mother's biological children and thus not be the first child*/

**not living in the household
recode amotch00 (1=1 "yes") (2=0 "no") (-9 -8 -1=.), gen (other_children)
/*does main respondent has given birth to any other children who is not living in the household?*/
/*this is part of the self-completion and around 600 MAIN have not filled it in*/
 
rename amotcn00 num_other_cld
recode num_other_cld -9 -8 -1=.
/*number of other children the main respondent has given birth to who are not living in the household?*/

*for those whose child has died
*children who were born alive and then died
gen other_cld_born_alive=0
foreach i in a0 b0 c0 d0 e0 f0 g0 h0 i0 {
replace other_cld_born_alive=other_cld_born_alive+1 if amlive`i'==1
}
recode other_cld_born_alive 0=. if other_children==0
recode other_cld_born_alive 0=. if other_children==.

*

*children who were born stillborn
gen other_cld_stillborn=0
foreach i in a0 b0 c0 d0 e0 f0 g0 h0 i0 {
replace other_cld_stillborn=other_cld_stillborn+1 if amlive`i'==2
}
*162 cases where the child was stillborn
recode other_cld_stillborn 0=. if other_children==0
recode other_cld_stillborn 0=. if other_children==.

*MAIN has other children who were born alive (who may or may not be alive now)
gen other_live=1 if other_children==1 & (other_cld_stillborn<num_other_cld)
replace other_live=0 if other_children==1 & (other_cld_stillborn==num_other_cld)

/*NOTES
- there are some inconsistencies between the relationship between MAIN and hh members (amprel*) vs. CM relationship with hh members (AHCREL001)- 
I suspect that there are some problems with amprel* so I've decided to refer to the hh grid variable
- I have used the variable ADNSIB00 which is a DV variable obtained using information on the hh grid and I recode those children 
who have natural sibilings as higher order births
- Information on other children is part of the self-completion and around 600 MAIN have not filled it in - those who have been coded as first birth 
and have missing values on this observation were coded as first births*/

**first birth
gen first_birth=1 if natural_parent==0&other_live!=1
replace first_birth=0 if natural_parent==0&other_live==1
replace first_birth=0 if natural_parent==1
replace first_birth=. if natural_parent==0&other_children==.
recode first_birth 1=0 if ADNSIB00==1
recode first_birth .=1 if ADNSIB00==2
recode first_birth .=0 if ADNSIB00==1
label var first_birth "MCS CM is first born"


*********************
*****MCS SWEEP 4*****
*********************

*************
***OBESITY***
*************

***BMI
gen obese_4=dobflag
recode obese_4 1=0 2=1
lab var obese_4 "s4 cm obese 0 no, 1 yes"

gen overweight_4=dobflag
recode overweight_4  2=1
lab var overweight_4 "s4 cm overwt/obese 0 norm/underwt, 1 overwt/obese"

gen underweight_4=1 if dbmin4<12.91 & sex==0
replace underweight_4=0 if dbmin4>=12.91 & sex==0
replace underweight_4=1 if dbmin4<13.08 & sex==1
replace underweight_4=0 if dbmin4>=13.08 & sex==1

gen weight_4=1 if underweight_4==1
replace weight_4=2 if underweight_4!=1 & overweight_4!=1 & obese_4!=1
replace weight_4=3 if overweight_4==1
replace weight_4=4 if obese_4==1
replace weight_4=. if dbmin4==.

label define weight_4 1"underweight" 2 "normal weight" 3"overweight" 4"obese"
label values weight_4 weight_4

*********************
****MOTHER OBESE*****
*********************

rename DDMBMI00 ddmbmi00
gen dmumbmi4=ddmbmi00
recode dmumbmi4 -1/-2=. 10/18.49=1 18.5/24.99=2 25/29.99=3 30/65=4
lab def bmi4 1 "underweight <18.5" 2 "normal 18.5-24.99" 3 "overweight 25-29.99" 4 "obese 30+"
lab val dmumbmi4 bmi4
lab var dmumbmi4 "S4 natural mother BMI at interview (4 cat)" 

replace ddmbmi00=mother_bmi_3 if ddmbmi00==-1|ddmbmi00==-2
replace  ddmbmi00=mother_bmi_2 if ddmbmi00==-1|ddmbmi00==-2
gen dmumbmi3=ddmbmi00
recode dmumbmi3 -1/-2=. 10/24.99=1 25/29.99=2 30/65=3
lab def bmi3 1 "uw/normal -24.99" 2 "overweight 25-29.99" 3 "obese 30+"
lab val dmumbmi3 bmi3
lab var dmumbmi3 "S4 natural mother BMI at interview (3 cat)" 

gen dmumbmi2=ddmbmi00
recode dmumbmi2 -1/-2=. 10/24.99=0 25/65=1
lab def bmi2 0 "uw/normal -24.99" 1 "ow/obese 25+"
lab val dmumbmi2 bmi2
lab var dmumbmi2 "S4 natural mother BMI at interview (2 cat)" 

gen dmumobese=ddmbmi00
recode dmumobese -1 -2=. 10/29.99=0 30/65=1
lab def obese 0 "uw/normal/ow -29.99" 1 "obese 30+"
lab val dmumobese obese
lab var dmumobese "S4 natural mother is obese (BMI>=30)" 

rename ddmbmi00 mother_bmi_4
recode mother_bmi_4 -2 -1=.

gen mother_over_obese=1 if dmumbmi3==2|dmumbmi3==3
replace mother_over_obese=0 if dmumbmi3==1
label var mother_over_obese "S4 mother is overweight/obese"

**********
***SES****
**********

**OECD equivalized income (quintiles)
rename DOECDUK0 doecduk0 
recode doecduk0 -1=.

**************
*****DIET*****
**************

gen d1drink=dmdrkma0
recode d1drink -8 95=. -1=0 2 4=1 1 3 5 6 7=2
lab def drink4 0 "None" 1 "water/art sweetened" 2 "Nat sweet/sweetened"
lab var d1drink "S4 c1 drinks between meals"
lab val d1drink drink4

gen sweet_drink=1 if dmdrkma0==1|dmdrkma0==2
replace sweet_drink=0 if dmdrkma0==-1|dmdrkma0==3|dmdrkma0==4|dmdrkma0==5|dmdrkma0==6|dmdrkma0==7
replace sweet_drink=. if dmdrkma0==-8|dmdrkma0==95
label var sweet_drink "S4 CM drinks sweet drinks or artificially sweet drinks"

gen d1snack=dmsnkma0
recode d1snack -8 95=. -1=0 4 5=1 1/3 6/10=2
lab def snack2 0 "fruit/veg/NA" 1 "Other food/snack"
lab def snack3 0 "None" 1 "fruit/veg" 2 "Other food/snack"
lab var d1snack "S4 c1 snacks between meals"
lab val d1snack snack3

*fruit dmfrtpa0
gen d1fruit=dmfrtpa0
recode d1fruit -9 -8 -1=. 0=3 1=2 2=1 3=0
lab def fruit 0 "3+" 1 "2" 2 "1" 3 "None"
lab val d1fruit fruit
lab var d1fruit "S4 c1 portions of fruit per day"

*CM eats breakfast all days of the week

recode dmbrkna0 -9 -8 -1 8=. 
gen breakfast=1 if dmbrkna0==7
replace breakfast=0 if dmbrkna0!=7 & dmbrkna0!=.

***********************
***PHYSICAL ACTIVITY***
***********************

* sport/exercise per week
gen dsport=.
replace dsport=0 if dmsehoa0==1|dmsehoa0==2|dmsehoa0==3
replace dsport=1 if dmsehoa0==4|dmsehoa0==5
replace dsport=2 if dmsehoa0==6|dmsehoa0==7
lab def freq 0 "3+ per wk" 1 "1-2 per wk" 2 "<1 per wk/never"
lab val dsport freq
lab var dsport "S4 freq sport/exercise per week"

*physical play with friends or siblings
gen dplays=.
replace dplays=0 if dmplfra0==1
replace dplays=1 if dmplfra0==2|dmplfra0==3|dmplfra0==4|dmplfra0==5
replace dplays=2 if dmplfra0==6|dmplfra0==7
lab def freq3 0 "5+ per wk" 1 "1-4 per wk" 2 "<1 per wk/never"
lab val dplays freq3
lab var dplays "S4 freq physical play with others per week"

*a parent does active play with child
lab def freq5 0 "3+ days/wk" 1 "1 or 2 days/wk" 2 "less than weekly" 3 "never"

gen dpplay=.
recode dpplay .=0 if dmactia0==1|dmactia0==2
recode dpplay .=0 if dpactia0==1|dpactia0==2
recode dpplay .=1 if dmactia0==3
recode dpplay .=1 if dpactia0==3
recode dpplay .=2 if dmactia0==4|dmactia0==5
recode dpplay .=2 if dpactia0==4|dpactia0==5
recode dpplay .=3 if dmactia0==6
recode dpplay .=3 if dpactia0==6
lab val dpplay freq5
lab var dpplay "S4 freq M or P does active play with CM"

gen dpplay2=dpplay
recode dpplay2 3=2

label define play 0 "3+ days/wk" 1 "1 or 2 days/wk" 2 "less than weekly"
label values dpplay2 play 

*a parent plays indoor games with child

gen dpgame=.
recode dpgame .=0 if dmgamea0==1|dmgamea0==2
recode dpgame .=0 if dpgamea0==1|dpgamea0==2
recode dpgame .=1 if dmgamea0==3
recode dpgame .=1 if dpgamea0==3
recode dpgame .=2 if dmgamea0==4|dmgamea0==5
recode dpgame .=2 if dpgamea0==4|dpgamea0==5
recode dpgame .=3 if dmgamea0==6
recode dpgame .=3 if dpgamea0==6
lab val dpgame freq5
lab var dpgame "S4 freq M or P plays indoor games with CM"

*a parent takes the child to the park or playground
gen dppark=.
recode dppark .=0 if dmwalka0==1|dmwalka0==2
recode dppark .=0 if dpwalka0==1|dpwalka0==2
recode dppark .=1 if dmwalka0==3
recode dppark .=1 if dpwalka0==3
recode dppark .=2 if dmwalka0==4|dmwalka0==5
recode dppark .=2 if dpwalka0==4|dpwalka0==5
recode dppark .=2 if dmwalka0==6
recode dppark .=2 if dpwalka0==6
label values dppark play
lab var dppark "S4 freq M or P takes CM to park or playground"

*play out
rename dmploua0 dplayout
recode dplayout -9/-1=. 1=1 2=0
lab val dplayout ny


*TV watching
recode dmtvhoa0 (-9 -8 -1=.) (1 2 = 0) (3=1) (4 5 6 = 2)
gen tv=dmtvhoa0

label define tv 0 "less than 1 h" 1 "1 to under 3h" 2 "3 h or more"
label val tv tv

**computer use
recode dmcompa0 (-9 -8 -1=.) (1 2 =0) (3=1) (4 5 6=2)
gen pc=dmcompa0

label define pc 1 " less than 1 h" 2 "1 to under 3 h" 3 "3 hr or more"   
label var pc pc

*bedtime
gen bedtime_irregular=1 if dbedtimey==7
replace bedtime_irregular=0 if dbedtimey!=7 & dbedtimey!=.
label var bedtime_irregular "S4 irregular bedtime"

*parent eats evening meal with CM
recode dmevwzaa -9 -8 -1=.
recode dmevwzab -9 -8 -1=.
recode dmevwzac -9 -8 -1=.
recode dmevwzad -9 -8 -1=.

gen parentmeal=0 if dmevwzaa!=.

foreach i in a b c d  {
replace parentmeal=1 if dmevwza`i'==2  
}
*

*************************************************************************************************************************************************************************************************************************************

*******************************
****SUB-POP GROUP & WEIGHTS****
*******************************

gen sub4=mother_main_1==1 & single_birth==1 & obese_4!=.&doecduk0!=.&main_ethnicity!=.&d1fruit!=.&dsport!=.&dpplay2!=.&dppark!=.&tv!=.&pc!=.&sweet_drink!=.&breakfast!=.&bedtime!=.&dparks!=.&smoke_preg!=.&breastfeed!=.&solid_food_before_4!=.&underweight_4!=1&mother_over_obese!=.
 
replace dovwt2=. if dovwt2<0
svyset sptn00 [pweight=dovwt2], strata (pttype2) fpc(nh2)

*******************************************
*******VARIABLES CREATION FOR ANALYSYS*****
*******************************************

gen low_income4=1 if doecduk0==1|doecduk0==2
replace low_income4=0 if doecduk0==3|doecduk0==4|doecduk0==5

gen bottom_income4=1 if doecduk0==1
replace bottom_income4=0 if doecduk0!=1 & doecduk0!=.

gen higher_income4=1 if low_income4==0
replace higher_income4=0 if low_income4==1

gen top_income4=1 if doecduk0==4|doecduk0==5
replace top_income4=0 if doecduk0==1|doecduk0==2|doecduk0==3

tab d1fruit, gen(fruit)
tab dsport, gen(sport) 
tab dpplay2, gen (play)
tab dppark, gen (park)
tab tv, gen (tv) 
tab pc, gen (pc)

gen indian_low=(indian*low_income4)
gen black_low=(black*low_income4)
gen pakibangla_low=(pakibangla*low_income4)

gen indian_top=(indian*top_income4)
gen black_top=(black*top_income4)
gen pakibangla_top=(pakibangla*top_income4)

gen no_breastfeeding=1 if some_breastfeeding==0
replace no_breastfeeding=0 if some_breastfeeding==1

gen no_fruit=1 if d1fruit==3
replace no_fruit=0 if d1fruit==0|d1fruit==1|d1fruit==2

gen no_breakfast=1 if breakfast==0
replace no_breakfast=0 if breakfast==1

gen no_meal=1 if parentmeal==0
replace no_meal=0 if parentmeal==1

gen no_sport=1 if dsport==2
replace no_sport=0 if dsport==0|dsport==1

gen no_play=1 if dpplay2==2
replace no_play=0 if dpplay2==0|dpplay2==1

gen screen_time=0 if tv==0&pc==0
replace screen_time=1 if tv==1|tv==2|pc==1|pc==2
label define screen 0"less than 1 hour" 1"1+ hours" 
label values screen_time screen

gen irregular_bedtime=bedtime

gen no_playpark=1 if dppark==2
replace no_playpark=0 if dppark==0|dppark==1

*****************************
*****Descriptive analyses ***
*****************************

tab doecduk0 if main_ethnicity==1 & sub4==1
tab doecduk0 if main_ethnicity==2 & sub4==1
tab doecduk0 if main_ethnicity==3 & sub4==1
tab doecduk0 if main_ethnicity==4 & sub4==1

tab income_tert4 if main_ethnicity==1 & sub4==1
tab income_tert4 if main_ethnicity==2 & sub4==1
tab income_tert4 if main_ethnicity==3 & sub4==1
tab income_tert4 if main_ethnicity==4 & sub4==1

*Income gradients by ethnicity and income
svy, subpop (sub4): tab overweight_4 doecduk0 if main_ethnicity==1, col
svy, subpop (sub4): tab overweight_4 doecduk0 if main_ethnicity==2, col
svy, subpop (sub4): tab overweight_4 doecduk0 if main_ethnicity==3, col
svy, subpop (sub4): tab overweight_4 doecduk0 if main_ethnicity==4, col
svy, subpop (sub4): tab overweight_4 doecduk0, col

svy, subpop (sub4): tab overweight_4 low_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab overweight_4 low_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab overweight_4 low_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab overweight_4 low_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab overweight_4 low_income4, col

*Smoking during pregnancy

svy, subpop (sub4): tab smoke_preg higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab smoke_preg higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab smoke_preg higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab smoke_preg higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab smoke_preg higher_income4, col

*Breastfeeding

svy, subpop (sub4): tab no_breastfeeding higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab no_breastfeeding higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab no_breastfeeding higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab no_breastfeeding higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab no_breastfeeding higher_income4, col

*Introduction to solid food before 4 months

svy, subpop (sub4): tab solid_food_before_4 higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab solid_food_before_4 higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab solid_food_before_4 higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab solid_food_before_4 higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab solid_food_before_4 higher_income4, col

*Mother is obese/overweight

svy, subpop (sub4): tab mother_over_obese higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab mother_over_obese higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab mother_over_obese higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab mother_over_obese higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab mother_over_obese higher_income4, col

*Sweet drinks between meals

svy, subpop (sub4): tab sweet_drink higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab sweet_drink higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab sweet_drink higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab sweet_drink higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab sweet_drink higher_income4, col

* Fruit portions per day

svy, subpop (sub4): tab no_fruit higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab no_fruit higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab no_fruit higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab no_fruit higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab no_fruit higher_income4, col

* CM eats breakfast all days of the week

svy, subpop (sub4): tab no_breakfast higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab no_breakfast higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab no_breakfast higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab no_breakfast higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab no_breakfast higher_income4, col

*Parent eats evening meal with CM
svy, subpop (sub4): tab no_meal higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab no_meal higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab no_meal higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab no_meal higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab no_meal higher_income4, col

* Sport per week

svy, subpop (sub4): tab no_sport higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab no_sport higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab no_sport higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab no_sport higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab no_sport higher_income4, col

* Parent does active playing with child every week

svy, subpop (sub4): tab no_play higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab no_play higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab no_play higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab no_play higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab no_play higher_income4, col

* Regular bedtime

svy, subpop (sub4): tab irregular_bedtime higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab irregular_bedtime higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab irregular_bedtime higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab irregular_bedtime higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab irregular_bedtime higher_income4, col

* Parent takes child to the park

svy, subpop (sub4): tab no_playpark higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab no_playpark higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab no_playpark higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab no_playpark higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab no_playpark higher_income4, col

* Tv watching or PC

svy, subpop (sub4): tab screen_time higher_income4 if main_ethnicity==1, col
svy, subpop (sub4): tab screen_time higher_income4 if main_ethnicity==2, col
svy, subpop (sub4): tab screen_time higher_income4 if main_ethnicity==3, col
svy, subpop (sub4): tab screen_time higher_income4 if main_ethnicity==4, col
svy, subpop (sub4): tab screen_time higher_income4, col

*****************************
*****Regression models ******
*****************************

svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low girl
estimates store m1	 		 
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low smoke_preg no_breastfeeding solid_food_before_4 girl
estimates store m2
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low sweet_drink no_fruit no_breakfast no_meal girl
estimates store m3
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low no_sport no_play irregular_bedtime no_playpark screen_time girl
estimates store m4
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low mother_over_obese girl    
estimates store m5
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low smoke_preg no_breastfeeding solid_food_before_4 sweet_drink no_fruit no_breakfast no_meal no_sport no_play irregular_bedtime no_playpark screen_time mother_over_obese girl     
estimates store m6

*************

***Model 1
*White
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low girl

margins, at (low_income4==1 indian==0 pakibangla==0 black==0 indian_low==0 pakibangla_low==0 black_low==0) ///
		 at (low_income4==0 indian==0 pakibangla==0 black==0 indian_low==0 pakibangla_low==0 black_low==0) subpop(sub4) vce(unconditional) post

		 nlcom (risk_ratio: _b[1._at]/_b[2._at])

*Indian
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low girl

margins, at (low_income4==1 indian==1 pakibangla==0 black==0 indian_low==1 pakibangla_low==0 black_low==0) ///
		 at (low_income4==0 indian==1 pakibangla==0 black==0 indian_low==0 pakibangla_low==0 black_low==0) subpop(sub4) vce(unconditional) post

		 nlcom (risk_ratio: _b[1._at]/_b[2._at])

*Pakistani/Bangladeshi
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low girl

margins, at (low_income4==1 indian==0 pakibangla==1 black==0 indian_low==0 pakibangla_low==1 black_low==0) ///
		 at (low_income4==0 indian==0 pakibangla==1 black==0 indian_low==0 pakibangla_low==0 black_low==0) subpop(sub4) vce(unconditional) post

		 nlcom (risk_ratio: _b[1._at]/_b[2._at])

*Black African/Caribbean
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low girl

margins, at (low_income4==1 indian==0 pakibangla==0 black==1 indian_low==0 pakibangla_low==0 black_low==1) ///
		 at (low_income4==0 indian==0 pakibangla==0 black==1 indian_low==0 pakibangla_low==0 black_low==0) subpop(sub4) vce(unconditional) post

		 nlcom (risk_ratio: _b[1._at]/_b[2._at])

*** Model 6
*White
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low smoke_preg no_breastfeeding solid_food_before_4 sweet_drink no_fruit no_breakfast no_meal no_sport no_play irregular_bedtime no_playpark screen_time mother_over_obese girl 
 
margins, at ((means) _all  (asobserved)low_income4==1 indian==0 pakibangla==0 black==0 indian_low==0 pakibangla_low==0 black_low==0) ///
		 at ((means) _all  (asobserved)low_income4==0 indian==0 pakibangla==0 black==0 indian_low==0 pakibangla_low==0 black_low==0) subpop(sub4) vce(unconditional) post

		 nlcom (risk_ratio: _b[1._at]/_b[2._at])
		 
*Indian		 

svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low smoke_preg no_breastfeeding solid_food_before_4 sweet_drink no_fruit no_breakfast no_meal no_sport no_play irregular_bedtime no_playpark screen_time mother_over_obese girl
 
margins, at ((means) _all  (asobserved)low_income4==1 indian==1 pakibangla==0 black==0 indian_low==1 pakibangla_low==0 black_low==0) ///
		 at ((means) _all  (asobserved)low_income4==0 indian==1 pakibangla==0 black==0 indian_low==0 pakibangla_low==0 black_low==0) subpop(sub4) vce(unconditional) post

		 nlcom (risk_ratio: _b[1._at]/_b[2._at])
		 
		 
*Pakistani/Bangladeshi		 
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low smoke_preg no_breastfeeding solid_food_before_4 sweet_drink no_fruit no_breakfast no_meal no_sport no_play irregular_bedtime no_playpark screen_time mother_over_obese girl
 
margins, at ((means) _all  (asobserved)low_income4==1 indian==0 pakibangla==1 black==0 indian_low==0 pakibangla_low==1 black_low==0) ///
		 at ((means) _all  (asobserved)low_income4==0 indian==0 pakibangla==1 black==0 indian_low==0 pakibangla_low==0 black_low==0) subpop(sub4) vce(unconditional) post

		 nlcom (risk_ratio: _b[1._at]/_b[2._at])
 
*Black African/Caribbean
svy, subpop (sub4): logistic overweight_4 low_income4 indian pakibangla black indian_low pakibangla_low black_low smoke_preg no_breastfeeding solid_food_before_4 sweet_drink no_fruit no_breakfast no_meal no_sport no_play irregular_bedtime no_playpark screen_time mother_over_obese girl
 
margins, at ((means) _all  (asobserved)low_income4==1 indian==0 pakibangla==1 black==1 indian_low==0 pakibangla_low==0 black_low==1) ///
		 at ((means) _all  (asobserved)low_income4==0 indian==0 pakibangla==1 black==1 indian_low==0 pakibangla_low==0 black_low==0) subpop(sub4) vce(unconditional) post

		 nlcom (risk_ratio: _b[1._at]/_b[2._at])		 

*Overall gradient
svy, subpop (sub4): logistic overweight_4 low_income4

margins, at (low_income4==1) ///
		 at (low_income4==0) subpop(sub4) vce(unconditional) post

		 nlcom (risk_ratio: _b[1._at]/_b[2._at])




